==> odoo_addon_converter-13.0.3.2.0.1.tar.gz: odoo_addon_converter-13.0.3.2.0.1/xref.py <==
##############################################################################
#
#    Converter Odoo module
#    Copyright (C) 2020 XCG Consulting <https://xcg-consulting.fr>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from typing import Any, Dict, Optional, Union

from odoo import models

from .base import Converter, NewinstanceType
from .models.ir_model_data import _XREF_IMD_MODULE


# TODO dans quel cas ça ne pourrait pas être un instance getter???
class Xref(Converter):
    def __init__(
        self, module: str = _XREF_IMD_MODULE, is_instance_getter: bool = True
    ):
        super().__init__()
        self._module = module
        self._is_instance_getter = is_instance_getter

    def odoo_to_message(
        self, instance: models.Model, ctx: Optional[Dict] = None
    ) -> Any:
        if not instance:
            return ""
        return instance.env["ir.model.data"].object_to_xmlid(
            instance, module=self._module
        )

    def get_instance(
        self, odoo_env, message_data
    ) -> Optional[Union[models.Model, NewinstanceType]]:
        return odoo_env.ref(
            ".".join([self._module, message_data]), raise_if_not_found=False
        )

    def post_hook(self, instance: models.Model, message_data):
        # add xmlid to the newly created object
        instance.env["ir.model.data"].set_xmlid(
            instance, message_data, module=self._module, only_when_missing=True
        )

    def is_instance_getter(self) -> bool:
        return self._is_instance_getter

==> odoo_addon_converter-17.0.1.1.0.tar.gz: odoo_addon_converter-17.0.1.1.0/xref.py <==
##############################################################################
#
#    Converter Odoo module
#    Copyright © 2020 XCG Consulting <https://xcg-consulting.fr>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from typing import Any

from odoo import models

from .base import Converter, NewinstanceType
from .models.ir_model_data import _XREF_IMD_MODULE


# TODO dans quel cas ça ne pourrait pas être un instance getter???
class Xref(Converter):
    """This converter represents an external reference, using the standard xmlid with a
    custom module name.
    """

    def __init__(self, module: str = _XREF_IMD_MODULE, is_instance_getter: bool = True):
        super().__init__()
        self._module = module
        self._is_instance_getter = is_instance_getter

    def odoo_to_message(self, instance: models.Model, ctx: dict | None = None) -> Any:
        if not instance:
            return ""
        return instance.env["ir.model.data"].object_to_xmlid(
            instance, module=self._module
        )

    def get_instance(
        self, odoo_env, message_data
    ) -> None | models.Model | NewinstanceType:
        return odoo_env.ref(
            ".".join([self._module, message_data]), raise_if_not_found=False
        )

    def post_hook(self, instance: models.Model, message_data):
        # add xmlid to the newly created object
        instance.env["ir.model.data"].set_xmlid(
            instance, message_data, module=self._module, only_when_missing=True
        )

    def is_instance_getter(self) -> bool:
        return self._is_instance_getter
